==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/22/22dcd39c8c306389babd59062403a0f8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Stats/FetchOptions/EmailStatOptions.php */
class __TwigTemplate_6988da61a3017dba3b629c00aa9e5dcf extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\EmailBundle\\Stats\\FetchOptions;

use Mautic\\StatsBundle\\Event\\Options\\FetchOptions;

class EmailStatOptions extends FetchOptions
{
    private array \$ids = [];

    /**
     * @var int|null
     */
    private \$companyId;

    /**
     * @var int|null
     */
    private \$campaignId;

    /**
     * @var int|null
     */
    private \$segmentId;

    private array \$filters = [];

    private bool \$canViewOthers = false;

    /**
     * @var string
     */
    private \$unit;

    /**
     * @return \$this
     */
    public function setEmailIds(array \$ids)
    {
        \$this->ids = \$ids;

        return \$this;
    }

    /**
     * @return array
     */
    public function getEmailIds()
    {
        return \$this->ids;
    }

    /**
     * @return int|null
     */
    public function getCompanyId()
    {
        return \$this->companyId;
    }

    /**
     * @param int|null \$companyId
     *
     * @return \$this;
     */
    public function setCompanyId(\$companyId)
    {
        \$this->companyId = \$companyId;

        return \$this;
    }

    /**
     * @return int|null
     */
    public function getCampaignId()
    {
        return \$this->campaignId;
    }

    /**
     * @param int|null \$campaignId
     *
     * @return \$this;
     */
    public function setCampaignId(\$campaignId)
    {
        \$this->campaignId = \$campaignId;

        return \$this;
    }

    /**
     * @return int|null
     */
    public function getSegmentId()
    {
        return \$this->segmentId;
    }

    /**
     * @param int|null \$segmentId
     *
     * @return \$this;
     */
    public function setSegmentId(\$segmentId)
    {
        \$this->segmentId = \$segmentId;

        return \$this;
    }

    /**
     * @return array
     */
    public function getFilters()
    {
        return \$this->filters;
    }

    /**
     * @return \$this
     */
    public function setFilters(array \$filters)
    {
        \$this->filters = \$filters;

        return \$this;
    }

    public function canViewOthers(): bool
    {
        return \$this->canViewOthers;
    }

    /**
     * @param bool \$canViewOthers
     *
     * @return \$this
     */
    public function setCanViewOthers(\$canViewOthers)
    {
        \$this->canViewOthers = \$canViewOthers;

        return \$this;
    }

    /**
     * @return string
     */
    public function getUnit()
    {
        return \$this->unit;
    }

    /**
     * @param string \$unit
     *
     * @return \$this
     */
    public function setUnit(\$unit)
    {
        \$this->unit = \$unit;

        return \$this;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Stats/FetchOptions/EmailStatOptions.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Stats/FetchOptions/EmailStatOptions.php", "/var/www/mautic-ktn/app/bundles/EmailBundle/Stats/FetchOptions/EmailStatOptions.php");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/22/22dcd39c8c306389babd59062403a0f8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Stats/FetchOptions/EmailStatOptions.php */
class __TwigTemplate_6988da61a3017dba3b629c00aa9e5dcf extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\EmailBundle\\Stats\\FetchOptions;

use Mautic\\StatsBundle\\Event\\Options\\FetchOptions;

class EmailStatOptions extends FetchOptions
{
    private array \$ids = [];

    /**
     * @var int|null
     */
    private \$companyId;

    /**
     * @var int|null
     */
    private \$campaignId;

    /**
     * @var int|null
     */
    private \$segmentId;

    private array \$filters = [];

    private bool \$canViewOthers = false;

    /**
     * @var string
     */
    private \$unit;

    /**
     * @return \$this
     */
    public function setEmailIds(array \$ids)
    {
        \$this->ids = \$ids;

        return \$this;
    }

    /**
     * @return array
     */
    public function getEmailIds()
    {
        return \$this->ids;
    }

    /**
     * @return int|null
     */
    public function getCompanyId()
    {
        return \$this->companyId;
    }

    /**
     * @param int|null \$companyId
     *
     * @return \$this;
     */
    public function setCompanyId(\$companyId)
    {
        \$this->companyId = \$companyId;

        return \$this;
    }

    /**
     * @return int|null
     */
    public function getCampaignId()
    {
        return \$this->campaignId;
    }

    /**
     * @param int|null \$campaignId
     *
     * @return \$this;
     */
    public function setCampaignId(\$campaignId)
    {
        \$this->campaignId = \$campaignId;

        return \$this;
    }

    /**
     * @return int|null
     */
    public function getSegmentId()
    {
        return \$this->segmentId;
    }

    /**
     * @param int|null \$segmentId
     *
     * @return \$this;
     */
    public function setSegmentId(\$segmentId)
    {
        \$this->segmentId = \$segmentId;

        return \$this;
    }

    /**
     * @return array
     */
    public function getFilters()
    {
        return \$this->filters;
    }

    /**
     * @return \$this
     */
    public function setFilters(array \$filters)
    {
        \$this->filters = \$filters;

        return \$this;
    }

    public function canViewOthers(): bool
    {
        return \$this->canViewOthers;
    }

    /**
     * @param bool \$canViewOthers
     *
     * @return \$this
     */
    public function setCanViewOthers(\$canViewOthers)
    {
        \$this->canViewOthers = \$canViewOthers;

        return \$this;
    }

    /**
     * @return string
     */
    public function getUnit()
    {
        return \$this->unit;
    }

    /**
     * @param string \$unit
     *
     * @return \$this
     */
    public function setUnit(\$unit)
    {
        \$this->unit = \$unit;

        return \$this;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Stats/FetchOptions/EmailStatOptions.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Stats/FetchOptions/EmailStatOptions.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Stats/FetchOptions/EmailStatOptions.php");
    }
}
